==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/integration-tests/it-producer/src/main/java/org/apache/servicecomb/it/schema/ApiOperationJaxrsSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.it.schema;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;

import org.apache.servicecomb.provider.rest.common.RestSchema;

import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

@RestSchema(schemaId = "apiOperationJaxrsSchemaTest")
@Path("/v1/apiOperationJaxrsHello")
public class ApiOperationJaxrsSchema {

  @Path("/sayHi")
  @GET
  @Produces("text/plain;charset=UTF-8")
  @ApiOperation(value = "", nickname = "sayHi")
  public String sayHello() {
    return "ApiOperationJaxrsSchema#sayHello";
  }

  @Path("/sayHello")
  @GET
  @Produces("application/json;charset=UTF-8")
  @ApiOperation(value = "", nickname = "sayHello")
  public String sayHello(@ApiParam("name") String name) {
    return name;
  }
}

==> apache-servicecomb-java-chassis-distribution-2.1.1-src.zip: apache-servicecomb-java-chassis-distribution-2.1.1-src/integration-tests/it-producer/src/main/java/org/apache/servicecomb/it/schema/ApiOperationJaxrsSchema.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.it.schema;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;

import org.apache.servicecomb.provider.rest.common.RestSchema;

import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

@RestSchema(schemaId = "apiOperationJaxrsSchemaTest")
@Path("/v1/apiOperationJaxrsHello")
public class ApiOperationJaxrsSchema {

  @Path("/sayHi")
  @GET
  @Produces("text/plain;charset=UTF-8")
  @ApiOperation(value = "", nickname = "sayHi")
  public String sayHello(Long index) {
    return "ApiOperationJaxrsSchema#sayHello" + index;
  }

  @Path("/sayHello")
  @GET
  @Produces("application/json;charset=UTF-8")
  @ApiOperation(value = "", nickname = "sayHello")
  public String sayHello(@ApiParam("name") String name) {
    return name;
  }
}
